#!/bin/sh
#-----------------------------------------------------------#
# check.sh: 
#-----------------------------------------------------------#
# 処理概要: パッケージのインストール状況を確認する
#-----------------------------------------------------------#
# 引数: なし
#-----------------------------------------------------------#
# 2009/2/20 SoSO
#-----------------------------------------------------------#

#-----------------------------------------------------------#
# 前処理
#-----------------------------------------------------------#
cd $(dirname $0)
SCRPT_HOME=$(pwd)

# 共通設定ファイルの読み込み
COMMON_SH=$SCRPT_HOME/common.sh
if [ -f $COMMON_SH ]; then
	. $COMMON_SH
else
	echo "[エラー] ${COMMON_SH} が存在しません。"
	exit 1
fi

# ログ
LOG=$_DRV_LOG_

LogStart $LOG

#-----------------------------------------------------------#
# main
#-----------------------------------------------------------#
rc=0

for aRPM in $(ls -1 $DRV_DIR/*.rpm)
do
    pkgName=$(rpm -qp --qf="%{NAME}" $aRPM)
    rpm -q $pkgName > /dev/null 2>&1
    if [ $? -ne 0 ]; then
      continue
    fi
    pkgArch=$(rpm -qp --qf="%{ARCH}" $aRPM)
    pkgVer=$(rpm -qp --qf="%{VERSION}-%{RELEASE}" $aRPM)
    instVer=$(rpm -q --qf="%{VERSION}-%{RELEASE}" "$pkgName-$pkgVer.$pkgArch")
    if [ "x$instVer" = "x$pkgVer" ]; then
        LogWrite $LOG " [OK]  パッケージ $pkgName.$pkgArch のアップデートに成功しました。"
    else
        LogWrite $LOG "[エラー] パッケージ $pkgName.$pkgArch のアップデートに失敗しました。"
        rc=16
    fi
done

#-----------------------------------------------------------#
# 後処理
#-----------------------------------------------------------#
LogEnd $LOG

exit $rc
